@@ -138,6 +138,22 @@ TEST(DOMBox, Load)
   EXPECT_EQ(sdf::ErrorCode::ELEMENT_MISSING, errors[0].Code());
   EXPECT_NE(std::string::npos, errors[0].Message().find("missing a <size>"));
   EXPECT_NE(nullptr, box.Element());
+
+  // Define <size> element description
+  sdf::ElementPtr sizeDesc(new sdf::Element());
+  sizeDesc->SetName("size");
+  sizeDesc->AddValue("vector3", "1 1 1", true, "size vector");
+  sdf->AddElementDescription(sizeDesc);
+
+  // Now add the element and assign a negative value
+  sdf::ElementPtr sizeElem = sdf->AddElement("size");
+  sizeElem->Set<gz::math::Vector3d>(gz::math::Vector3d(-1, -1, -1));
+
+  // Load and check behavior
+  errors = box.Load(sdf);
+  ASSERT_EQ(0u, errors.size());
+  EXPECT_NE(nullptr, box.Element());
+  EXPECT_EQ(gz::math::Vector3d::One, box.Size());  // Defaulted to 1,1,1
 }
 
 /////////////////////////////////////////////////
@@ -155,7 +171,7 @@ TEST(DOMBox, CalculateInertial)
 {
   sdf::Box box;
 
-  // density of aluminium
+  // density of Aluminum
   double density = 2710;
 
   // Invalid dimensions leading to std::nullopt return in
@@ -170,15 +186,14 @@ TEST(DOMBox, CalculateInertial)
   box.SetSize(gz::math::Vector3d(l, w, h));
 
   double expectedMass = box.Shape().Volume() * density;
-  double ixx = (1.0/12.0) * expectedMass * (w*w + h*h);
-  double iyy = (1.0/12.0) * expectedMass * (l*l + h*h);
-  double izz = (1.0/12.0) * expectedMass * (l*l + w*w);
+  double ixx = (1.0 / 12.0) * expectedMass * (w * w + h * h);
+  double iyy = (1.0 / 12.0) * expectedMass * (l * l + h * h);
+  double izz = (1.0 / 12.0) * expectedMass * (l * l + w * w);
 
   gz::math::MassMatrix3d expectedMassMat(
-    expectedMass,
-    gz::math::Vector3d(ixx, iyy, izz),
-    gz::math::Vector3d::Zero
-  );
+      expectedMass,
+      gz::math::Vector3d(ixx, iyy, izz),
+      gz::math::Vector3d::Zero);
 
   gz::math::Inertiald expectedInertial;
   expectedInertial.SetMassMatrix(expectedMassMat);
@@ -189,9 +204,9 @@ TEST(DOMBox, CalculateInertial)
   ASSERT_NE(std::nullopt, boxInertial);
   EXPECT_EQ(expectedInertial, *boxInertial);
   EXPECT_EQ(expectedInertial.MassMatrix().DiagonalMoments(),
-    boxInertial->MassMatrix().DiagonalMoments());
+            boxInertial->MassMatrix().DiagonalMoments());
   EXPECT_EQ(expectedInertial.MassMatrix().Mass(),
-    boxInertial->MassMatrix().Mass());
+            boxInertial->MassMatrix().Mass());
   EXPECT_EQ(expectedInertial.Pose(), boxInertial->Pose());
 }
 
@@ -219,14 +234,14 @@ TEST(DOMBox, ToElementErrorOutput)
   sdf::testing::RedirectConsoleStream redir(
       sdf::Console::Instance()->GetMsgStream(), &buffer);
 
-  #ifdef _WIN32
-    sdf::Console::Instance()->SetQuiet(false);
-    sdf::testing::ScopeExit revertSetQuiet(
+#ifdef _WIN32
+  sdf::Console::Instance()->SetQuiet(false);
+  sdf::testing::ScopeExit revertSetQuiet(
       []
       {
         sdf::Console::Instance()->SetQuiet(true);
       });
-  #endif
+#endif
 
   sdf::Box box;
   sdf::Errors errors;
