@@ -66,7 +66,7 @@ class sdf::Camera::Implementation
   /// \brief Camera trigger topic.
   public: std::string triggerTopic = "";
 
-  /// \brief Horizontal fied of view.
+  /// \brief Horizontal field of view.
   public: gz::math::Angle hfov{1.047};
 
   /// \brief Image width.
@@ -177,16 +177,16 @@ class sdf::Camera::Implementation
   /// \brief lens environment texture size.
   public: int lensEnvTextureSize{256};
 
-  /// \brief lens instrinsics fx.
+  /// \brief lens intrinsics fx.
   public: double lensIntrinsicsFx{277.0};
 
-  /// \brief lens instrinsics fy.
+  /// \brief lens intrinsics fy.
   public: double lensIntrinsicsFy{277.0};
 
-  /// \brief lens instrinsics cx.
+  /// \brief lens intrinsics cx.
   public: double lensIntrinsicsCx{160.0};
 
-  /// \brief lens instrinsics cy.
+  /// \brief lens intrinsics cy.
   public: double lensIntrinsicsCy{120.0};
 
   /// \brief lens projection fx
@@ -207,7 +207,7 @@ class sdf::Camera::Implementation
   /// \brief lens projection ty
   public: double lensProjectionTy{0.0};
 
-  /// \brief lens instrinsics s.
+  /// \brief lens intrinsics s.
   public: double lensIntrinsicsS{0.0};
 
   /// \brief True if this camera has custom intrinsics values
@@ -752,6 +752,9 @@ void Camera::SetSaveFramesPath(const std::string &_path)
 //////////////////////////////////////////////////
 bool Camera::operator==(const Camera &_cam) const
 {
+
+  // \todo(iche033) Remove in sdformat16
+  GZ_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
   return this->Name() == _cam.Name() &&
     this->HorizontalFov() == _cam.HorizontalFov() &&
     this->ImageWidth() == _cam.ImageWidth() &&
@@ -764,6 +767,7 @@ bool Camera::operator==(const Camera &_cam) const
     this->ImageNoise() == _cam.ImageNoise() &&
     this->VisibilityMask() == _cam.VisibilityMask() &&
     this->OpticalFrameId() == _cam.OpticalFrameId();
+  GZ_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
 }
 
 //////////////////////////////////////////////////
@@ -1332,8 +1336,11 @@ sdf::ElementPtr Camera::ToElement() const
         this->SegmentationType());
   }
 
+  // \todo(iche033) Remove in sdformat16
+  GZ_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
   elem->GetElement("optical_frame_id")->Set<std::string>(
       this->OpticalFrameId());
+  GZ_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
 
   return elem;
 }
