@@ -152,11 +152,13 @@ TEST(DOMCylinder, Load)
       << errors[1].Message();
   EXPECT_NE(nullptr, cylinder.Element());
 
-  // Add a radius element
+  // Add <radius> element description
   sdf::ElementPtr radiusDesc(new sdf::Element());
   radiusDesc->SetName("radius");
   radiusDesc->AddValue("double", "1.0", true, "radius");
   sdf->AddElementDescription(radiusDesc);
+
+  // Add radius element
   sdf::ElementPtr radiusElem = sdf->AddElement("radius");
   radiusElem->Set<double>(2.0);
 
@@ -167,6 +169,29 @@ TEST(DOMCylinder, Load)
   EXPECT_EQ(sdf::ErrorCode::ELEMENT_INVALID, errors[0].Code());
   EXPECT_NE(std::string::npos, errors[0].Message().find("Invalid <length>"))
       << errors[0].Message();
+
+  // Now add <length> element description
+  sdf::ElementPtr lengthDesc(new sdf::Element());
+  lengthDesc->SetName("length");
+  lengthDesc->AddValue("double", "1.0", true, "length");
+  sdf->AddElementDescription(lengthDesc);
+
+  // Add length element and test negative radius
+  sdf::ElementPtr lengthElem = sdf->AddElement("length");
+  lengthElem->Set<double>(3.0);
+  radiusElem->Set<double>(-1.0);
+  errors = cylinder.Load(sdf);
+  ASSERT_EQ(0u, errors.size());
+  EXPECT_NE(nullptr, cylinder.Element());
+  EXPECT_DOUBLE_EQ(0.5, cylinder.Radius());  // Default to 0.5
+
+  // Test negative length
+  radiusElem->Set<double>(1.0);
+  lengthElem->Set<double>(-1.0);
+  errors = cylinder.Load(sdf);
+  ASSERT_EQ(0u, errors.size());
+  EXPECT_NE(nullptr, cylinder.Element());
+  EXPECT_DOUBLE_EQ(1.0, cylinder.Length());  // Default to 1.0
 }
 
 /////////////////////////////////////////////////
@@ -187,7 +212,7 @@ TEST(DOMCylinder, CalculateInertial)
 {
   sdf::Cylinder cylinder;
 
-  // density of aluminium
+  // density of Aluminum
   const double density = 2170;
 
   // Invalid dimensions leading to std::nullopt return in
