@@ -15,6 +15,7 @@
  *
 */
 #include <algorithm>
+#include <iostream>
 #include <string>
 #include <set>
 #include <utility>
@@ -77,6 +78,8 @@ FindSourceVertex(const ScopedGraph<T> &_graph,
   using DirectedEdge = typename ScopedGraph<T>::Edge;
   using Vertex = typename ScopedGraph<T>::Vertex;
   using VertexId = gz::math::graph::VertexId;
+  using VertexType = typename ScopedGraph<T>::VertexType;
+  using gz::math::graph::NullVertex;
   using EdgesType = std::vector<DirectedEdge>;
   using PairType = std::pair<const Vertex &, EdgesType>;
   EdgesType edges;
@@ -86,7 +89,7 @@ FindSourceVertex(const ScopedGraph<T> &_graph,
     _errors.push_back({ErrorCode::POSE_RELATIVE_TO_INVALID,
         "Unable to resolve pose, invalid vertex[" + std::to_string(_id) + "] "
         "in PoseRelativeToGraph."});
-    return PairType(Vertex::NullVertex, EdgesType());
+    return PairType(NullVertex<VertexType>(), EdgesType());
   }
 
   if (_id == _graph.ScopeVertexId())
@@ -106,7 +109,7 @@ FindSourceVertex(const ScopedGraph<T> &_graph,
       _errors.push_back({ErrorCode::POSE_RELATIVE_TO_GRAPH_ERROR,
           "PoseRelativeToGraph error: multiple incoming edges to "
           "current vertex [" + vertex.get().Name() + "]."});
-      return PairType(Vertex::NullVertex, EdgesType());
+      return PairType(NullVertex<VertexType>(), EdgesType());
     }
     auto const &edge = incidentsTo.begin()->second;
     vertex = _graph.Graph().VertexFromId(edge.get().Vertices().first);
@@ -116,7 +119,7 @@ FindSourceVertex(const ScopedGraph<T> &_graph,
       _errors.push_back({ErrorCode::POSE_RELATIVE_TO_CYCLE,
           "PoseRelativeToGraph cycle detected, already visited vertex [" +
           vertex.get().Name() + "]."});
-      return PairType(Vertex::NullVertex, EdgesType());
+      return PairType(NullVertex<VertexType>(), EdgesType());
     }
     if (vertex.get().Id() == _graph.ScopeVertexId())
     {
@@ -129,7 +132,7 @@ FindSourceVertex(const ScopedGraph<T> &_graph,
   if (vertex.get().Id() != _graph.ScopeVertexId())
   {
     // Error, the root vertex is not the same as the the source
-    return PairType(Vertex::NullVertex, EdgesType());
+    return PairType(NullVertex<VertexType>(), EdgesType());
   }
 
   return PairType(vertex, edges);
@@ -157,6 +160,8 @@ FindSinkVertex(
   using DirectedEdge = typename ScopedGraph<T>::Edge;
   using Vertex = typename ScopedGraph<T>::Vertex;
   using VertexId = gz::math::graph::VertexId;
+  using VertexType = typename ScopedGraph<T>::VertexType;
+  using gz::math::graph::NullVertex;
   using EdgesType = std::vector<DirectedEdge>;
   using PairType = std::pair<const Vertex &, EdgesType>;
   EdgesType edges;
@@ -166,7 +171,7 @@ FindSinkVertex(
     _errors.push_back({ErrorCode::FRAME_ATTACHED_TO_INVALID,
         "Invalid vertex[" + std::to_string(_id) + "] "
         "in FrameAttachedToGraph."});
-    return PairType(Vertex::NullVertex, EdgesType());
+    return PairType(NullVertex<VertexType>(), EdgesType());
   }
 
   std::set<VertexId> visited;
@@ -180,7 +185,7 @@ FindSinkVertex(
       _errors.push_back({ErrorCode::FRAME_ATTACHED_TO_GRAPH_ERROR,
           "FrameAttachedToGraph error: multiple outgoing edges from "
           "current vertex [" + vertex.get().Name() + "]."});
-      return PairType(Vertex::NullVertex, EdgesType());
+      return PairType(NullVertex<VertexType>(), EdgesType());
     }
     auto const &edge = incidentsFrom.begin()->second;
     vertex = _graph.Graph().VertexFromId(edge.get().Vertices().second);
@@ -190,7 +195,7 @@ FindSinkVertex(
       _errors.push_back({ErrorCode::FRAME_ATTACHED_TO_CYCLE,
           "FrameAttachedToGraph cycle detected, already visited vertex [" +
           vertex.get().Name() + "]."});
-      return PairType(Vertex::NullVertex, EdgesType());
+      return PairType(NullVertex<VertexType>(), EdgesType());
     }
     visited.insert(vertex.get().Id());
     incidentsFrom = _graph.Graph().IncidentsFrom(vertex);
@@ -351,7 +356,7 @@ struct FrameWrapper : public WrapperBase
   {
   }
 
-  /// \brief Constructor from name, pose, and attachement data (without
+  /// \brief Constructor from name, pose, and attachment data (without
   /// sdf::Frame or sdf::InterfaceFrame)
   FrameWrapper(const std::string &_name, const gz::math::Pose3d &_rawPose,
                const std::string &_relativeTo, const std::string &_attachedTo)
