@@ -29,7 +29,7 @@
 #include "sdf/SDFImpl.hh"
 #include "sdf/World.hh"
 #include "sdf/parser.hh"
-#include "sdf/sdf_config.h"
+#include "sdf/config.hh"
 
 #include "FrameSemantics.hh"
 #include "ScopedGraph.hh"
