@@ -17,10 +17,9 @@
 
 #include <cstdlib>
 #include <fstream>
-#include <sstream>
 #include <functional>
-#include <list>
-#include <map>
+#include <iostream>
+#include <sstream>
 #include <string>
 #include <vector>
 
@@ -32,7 +31,7 @@
 #include "sdf/InstallationDirectories.hh"
 #include "sdf/SDFImpl.hh"
 #include "SDFImplPrivate.hh"
-#include "sdf/sdf_config.h"
+#include "sdf/config.hh"
 #include "EmbeddedSdf.hh"
 #include "Utils.hh"
 
@@ -474,12 +473,6 @@ void SDF::SetRoot(const ElementPtr _root)
   this->dataPtr->root = _root;
 }
 
-/////////////////////////////////////////////////
-void SDF::Root(const ElementPtr _root)
-{
-  this->SetRoot(_root);
-}
-
 /////////////////////////////////////////////////
 std::string SDF::FilePath() const
 {
