@@ -20,15 +20,17 @@
 #include <any>
 #include <filesystem>
 
-#include <gz/math.hh>
+#include <gz/math/Color.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/math/Vector2.hh>
+#include <gz/math/Vector3.hh>
 #include <gz/utils/Environment.hh>
 #include <gz/utils/SuppressWarning.hh>
 
+#include "sdf/parser.hh"
 #include "test_config.hh"
 #include "test_utils.hh"
 
-#include "sdf/sdf.hh"
-
 class SDFUpdateFixture
 {
   public:  std::string GetName() const {return this->name;}
@@ -290,14 +292,6 @@ TEST(SDF, SetRoot)
   elem->AddValue("bool", "true", false, "description");
   s.SetRoot(elem);
   EXPECT_EQ(elem, s.Root());
-
-  // Test deprecated setter, remove in libsdformat14
-  s.SetRoot(nullptr);
-  EXPECT_EQ(nullptr, s.Root());
-  GZ_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
-  s.Root(elem);
-  GZ_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
-  EXPECT_EQ(elem, s.Root());
 }
 
 ////////////////////////////////////////////////////
