@@ -22,7 +22,7 @@
 #include "sdf/parser.hh"
 #include "sdf/Surface.hh"
 #include "sdf/Types.hh"
-#include "sdf/sdf_config.h"
+#include "sdf/config.hh"
 #include "sdf/system_util.hh"
 #include "Utils.hh"
 
