@@ -50,8 +50,8 @@ TEST(DOMVisual, Construction)
     EXPECT_FALSE(semanticPose.Resolve(pose).empty());
   }
 
-  visual.SetRawPose({0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2});
-  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2),
+  visual.SetRawPose({0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2});
+  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2),
             visual.RawPose());
 
   visual.SetPoseRelativeTo("link");
@@ -68,6 +68,7 @@ TEST(DOMVisual, Construction)
   ASSERT_NE(nullptr, visual.Geom());
   EXPECT_EQ(sdf::GeometryType::EMPTY, visual.Geom()->Type());
   EXPECT_EQ(nullptr, visual.Geom()->BoxShape());
+  EXPECT_EQ(nullptr, visual.Geom()->ConeShape());
   EXPECT_EQ(nullptr, visual.Geom()->CylinderShape());
   EXPECT_EQ(nullptr, visual.Geom()->PlaneShape());
   EXPECT_EQ(nullptr, visual.Geom()->SphereShape());
@@ -88,7 +89,7 @@ TEST(DOMVisual, CopyConstructor)
   visual.SetName("test_visual");
   visual.SetCastShadows(false);
   visual.SetTransparency(0.345f);
-  visual.SetRawPose({0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2});
+  visual.SetRawPose({0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2});
   visual.SetVisibilityFlags(2u);
 
   visual.SetPoseRelativeTo("link");
@@ -102,7 +103,7 @@ TEST(DOMVisual, CopyConstructor)
   EXPECT_EQ("test_visual", visual.Name());
   EXPECT_FALSE(visual.CastShadows());
   EXPECT_FLOAT_EQ(0.345f, visual.Transparency());
-  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2),
+  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2),
             visual.RawPose());
   EXPECT_EQ("link", visual.PoseRelativeTo());
   ASSERT_TRUE(nullptr != visual.Material());
@@ -112,7 +113,7 @@ TEST(DOMVisual, CopyConstructor)
   EXPECT_EQ("test_visual", visual2.Name());
   EXPECT_FALSE(visual2.CastShadows());
   EXPECT_FLOAT_EQ(0.345f, visual2.Transparency());
-  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2),
+  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2),
             visual2.RawPose());
   EXPECT_EQ("link", visual2.PoseRelativeTo());
   ASSERT_TRUE(nullptr != visual2.Material());
@@ -127,7 +128,7 @@ TEST(DOMVisual, CopyAssignmentOperator)
   visual.SetName("test_visual");
   visual.SetCastShadows(false);
   visual.SetTransparency(0.345f);
-  visual.SetRawPose({0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2});
+  visual.SetRawPose({0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2});
   visual.SetVisibilityFlags(2u);
 
   visual.SetPoseRelativeTo("link");
@@ -142,7 +143,7 @@ TEST(DOMVisual, CopyAssignmentOperator)
   EXPECT_EQ("test_visual", visual.Name());
   EXPECT_FALSE(visual.CastShadows());
   EXPECT_FLOAT_EQ(0.345f, visual.Transparency());
-  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2),
+  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2),
             visual.RawPose());
   EXPECT_EQ("link", visual.PoseRelativeTo());
   ASSERT_TRUE(nullptr != visual.Material());
@@ -152,7 +153,7 @@ TEST(DOMVisual, CopyAssignmentOperator)
   EXPECT_EQ("test_visual", visual2.Name());
   EXPECT_FALSE(visual2.CastShadows());
   EXPECT_FLOAT_EQ(0.345f, visual2.Transparency());
-  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2),
+  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2),
             visual2.RawPose());
   EXPECT_EQ("link", visual2.PoseRelativeTo());
   ASSERT_TRUE(nullptr != visual2.Material());
@@ -167,7 +168,7 @@ TEST(DOMVisual, MoveConstructor)
   visual.SetName("test_visual");
   visual.SetCastShadows(false);
   visual.SetTransparency(0.345f);
-  visual.SetRawPose({0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2});
+  visual.SetRawPose({0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2});
   visual.SetVisibilityFlags(2u);
 
   visual.SetPoseRelativeTo("link");
@@ -181,7 +182,7 @@ TEST(DOMVisual, MoveConstructor)
   EXPECT_EQ("test_visual", visual2.Name());
   EXPECT_FALSE(visual2.CastShadows());
   EXPECT_FLOAT_EQ(0.345f, visual2.Transparency());
-  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2),
+  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2),
             visual2.RawPose());
   EXPECT_EQ("link", visual2.PoseRelativeTo());
   ASSERT_TRUE(nullptr != visual2.Material());
@@ -196,7 +197,7 @@ TEST(DOMVisual, MoveAssignmentOperator)
   visual.SetName("test_visual");
   visual.SetCastShadows(false);
   visual.SetTransparency(0.345f);
-  visual.SetRawPose({0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2});
+  visual.SetRawPose({0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2});
   visual.SetVisibilityFlags(2u);
 
   visual.SetPoseRelativeTo("link");
@@ -211,7 +212,7 @@ TEST(DOMVisual, MoveAssignmentOperator)
   EXPECT_EQ("test_visual", visual2.Name());
   EXPECT_FALSE(visual2.CastShadows());
   EXPECT_FLOAT_EQ(0.345f, visual2.Transparency());
-  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, IGN_PI_2, -IGN_PI, IGN_PI_2),
+  EXPECT_EQ(gz::math::Pose3d(0, -20, 30, GZ_PI_2, -GZ_PI, GZ_PI_2),
             visual2.RawPose());
   EXPECT_EQ("link", visual2.PoseRelativeTo());
   ASSERT_TRUE(nullptr != visual2.Material());
