@@ -37,7 +37,7 @@
 #include "sdf/World.hh"
 #include "sdf/parser.hh"
 #include "sdf/ParserConfig.hh"
-#include "sdf/sdf_config.h"
+#include "sdf/config.hh"
 
 #include "Converter.hh"
 #include "FrameSemantics.hh"
@@ -2725,12 +2725,6 @@ bool checkPoseRelativeToGraph(sdf::Errors &_errors, const sdf::Root *_root)
   return result;
 }
 
-//////////////////////////////////////////////////
-bool checkJointParentChildLinkNames(const sdf::Root *_root)
-{
-  return checkJointParentChildNames(_root);
-}
-
 //////////////////////////////////////////////////
 bool checkJointParentChildNames(const sdf::Root *_root)
 {
@@ -2872,7 +2866,7 @@ void checkScopedJointAxisExpressedInValues(
         const std::string xyzExpressedInLocal =
             sdf::SplitName(xyzExpressedIn).second;
 
-        // If a frame name is specfied, check that the frame exists.
+        // If a frame name is specified, check that the frame exists.
         if (!xyzExpressedIn.empty() &&
             !_scope->NameExistsInFrameAttachedToGraph(xyzExpressedIn))
         {
