@@ -37,7 +37,7 @@
 #include "sdf/SDFImpl.hh"
 #include "sdf/Visual.hh"
 #include "sdf/World.hh"
-#include "test_config.h"
+#include "test_config.hh"
 #include "test_utils.hh"
 
 /////////////////////////////////////////////////
@@ -55,9 +55,7 @@ TEST(IncludesTest, Includes)
 
   sdf::Root root;
   sdf::Errors errors = root.Load(worldFile);
-  for (auto e : errors)
-    std::cout << e.Message() << std::endl;
-  EXPECT_TRUE(errors.empty());
+  EXPECT_TRUE(errors.empty()) << errors;
 
   ASSERT_NE(nullptr, root.Element());
   EXPECT_EQ(worldFile, root.Element()->FilePath());
@@ -234,8 +232,6 @@ TEST(IncludesTest, Includes_15)
 
   sdf::Root root;
   sdf::Errors errors = root.Load(worldFile);
-  for (auto e : errors)
-    std::cout << e.Message() << std::endl;
   EXPECT_TRUE(errors.empty());
 
   ASSERT_NE(nullptr, root.Element());
@@ -349,20 +345,19 @@ TEST(IncludesTest, IncludeModelMissingConfig)
   sdf::Errors errors;
   ASSERT_TRUE(sdf::readString(stream.str(), sdfParsed, errors));
 
-  ASSERT_GE(1u, errors.size());
-  EXPECT_EQ(1u, errors.size());
-  std::cout << errors[0] << std::endl;
-  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::URI_LOOKUP);
-  EXPECT_NE(std::string::npos, errors[0].Message().find(
-      "Unable to resolve uri[box_missing_config] to model path")) << errors[0];
+  EXPECT_EQ(2u, errors.size());
+  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::FILE_READ);
   EXPECT_NE(std::string::npos, errors[0].Message().find(
+      "Could not find model.config or manifest.xml in")) << errors[0];
+  EXPECT_EQ(errors[1].Code(), sdf::ErrorCode::URI_LOOKUP);
+  EXPECT_NE(std::string::npos, errors[1].Message().find(
+      "Unable to resolve uri[box_missing_config] to model path")) << errors[1];
+  EXPECT_NE(std::string::npos, errors[1].Message().find(
       "box_missing_config] since it does not contain a model.config file"))
-    << errors[0];
+    << errors[1];
 
   sdf::Root root;
   errors = root.Load(sdfParsed);
-  for (auto e : errors)
-    std::cout << e.Message() << std::endl;
   EXPECT_TRUE(errors.empty());
 
   EXPECT_EQ(nullptr, root.Model());
@@ -439,7 +434,7 @@ TEST(IncludesTest, MergeInclude)
 
   // X_PM - Pose of original model (M) in parent model (P) frame. This is the
   // pose override in the //include tag.
-  const Pose3d X_PM(100, 0, 0, IGN_PI_4, 0, 0);
+  const Pose3d X_PM(100, 0, 0, GZ_PI_4, 0, 0);
   // X_MRw - Pose of the right wheel in the original model (M) as specified in
   // the SDFormat file.
   const Pose3d X_MRw(0.554282, -0.625029, -0.025, -1.5707, 0, 0);
@@ -496,7 +491,7 @@ TEST(IncludesTest, MergeInclude)
     // From SDFormat file
     // X_MS - Pose of sensor_frame (S) in the original model (M) as
     // specified in the SDF file.
-    const Pose3d X_MS(0, 1, 0, 0, IGN_PI_4, 0);
+    const Pose3d X_MS(0, 1, 0, 0, GZ_PI_4, 0);
     const Pose3d expectedPose = X_PM * X_MS;
     EXPECT_EQ(expectedPose, testPose);
   }
@@ -526,14 +521,14 @@ TEST(IncludesTest, MergeInclude)
     // left_wheel_joint's axis is expressed in __model__.
     auto joint = model->JointByName("test_model_parent");
     ASSERT_NE(nullptr, joint);
-    EXPECT_EQ(prefixedFrameName, joint->ParentLinkName());
+    EXPECT_EQ(prefixedFrameName, joint->ParentName());
   }
   // Check joint child set as __model__
   {
     // left_wheel_joint's axis is expressed in __model__.
     auto joint = model->JointByName("test_model_child");
     ASSERT_NE(nullptr, joint);
-    EXPECT_EQ(prefixedFrameName, joint->ChildLinkName());
+    EXPECT_EQ(prefixedFrameName, joint->ChildName());
   }
 
   // Verify that plugins get merged
@@ -555,6 +550,72 @@ TEST(IncludesTest, MergeInclude)
   EXPECT_FALSE(modelElem->HasElement("static"));
 }
 
+//////////////////////////////////////////////////
+TEST(IncludesTest, WorldMergeInclude)
+{
+  using gz::math::Pose3d;
+  sdf::ParserConfig config;
+  config.SetFindCallback(findFileCb);
+
+  sdf::Root root;
+  sdf::Errors errors = root.Load(
+      sdf::testing::TestFile("sdf", "world_merge_include.sdf"),
+      config);
+  EXPECT_TRUE(errors.empty()) << errors;
+
+  auto *world = root.WorldByIndex(0);
+  ASSERT_NE(nullptr, world);
+
+  std::string proxyFrameName;
+    proxyFrameName = "_merged__model_for_world_merge_include__model__";
+
+  auto *proxyFrame = world->FrameByName(proxyFrameName);
+  ASSERT_NE(nullptr, proxyFrame);
+
+  EXPECT_EQ(Pose3d(100, 0, 0, 0, 0, 0), proxyFrame->RawPose());
+
+  // Expect that the merged models have poses relative to the proxy frame
+  ASSERT_EQ(2, world->ModelCount());
+  auto *model1 = world->ModelByIndex(0);
+  ASSERT_NE(nullptr, model1);
+  EXPECT_EQ(proxyFrameName, model1->PoseRelativeTo());
+
+  auto *model2 = world->ModelByIndex(1);
+  ASSERT_NE(nullptr, model2);
+  EXPECT_EQ(proxyFrameName, model2->PoseRelativeTo());
+
+  // F1, since it had an empty attached_to in the original model, once it's
+  // merged, it should be attached to the proxy frame
+  auto *frame1 = world->FrameByName("F1");
+  ASSERT_NE(nullptr, frame1);
+  EXPECT_EQ(proxyFrameName, frame1->AttachedTo());
+
+  // Check that the joint was also merged
+  auto *joint1 = world->JointByName("J1");
+  ASSERT_NE(nullptr, joint1);
+}
+
+//////////////////////////////////////////////////
+TEST(IncludesTest, WorldMergeIncludeInvalidElements)
+{
+  std::string sdfString = R"(
+  <sdf version="1.10">
+    <world name="invalid_world">
+      <include merge="true">
+        <uri>test_model</uri>
+      </include>
+    </world>
+  </sdf>)";
+
+  sdf::ParserConfig config;
+  config.SetFindCallback(findFileCb);
+
+  sdf::Root root;
+  sdf::Errors errors = root.LoadSdfString(sdfString, config);
+  ASSERT_FALSE(errors.empty());
+  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::MERGE_INCLUDE_UNSUPPORTED);
+}
+
 //////////////////////////////////////////////////
 TEST(IncludesTest, MergeIncludePlacementFrame)
 {
@@ -585,7 +646,23 @@ TEST(IncludesTest, MergeIncludePlacementFrame)
 //////////////////////////////////////////////////
 TEST(IncludesTest, InvalidMergeInclude)
 {
+  // Redirect sdferr output
+  std::stringstream buffer;
+  sdf::testing::RedirectConsoleStream redir(
+      sdf::Console::Instance()->GetMsgStream(), &buffer);
+#ifdef _WIN32
+    sdf::Console::Instance()->SetQuiet(false);
+    sdf::testing::ScopeExit revertSetQuiet(
+        []
+        {
+        sdf::Console::Instance()->SetQuiet(true);
+        });
+#endif
+
   sdf::ParserConfig config;
+  // Set policies to Error to make sure nothing gets printed
+  config.SetWarningsPolicy(sdf::EnforcementPolicy::ERR);
+  config.SetUnrecognizedElementsPolicy(sdf::EnforcementPolicy::ERR);
   // Using the "file://" URI scheme to allow multiple search paths
   config.AddURIPath("file://", sdf::testing::TestFile("sdf"));
   config.AddURIPath("file://", sdf::testing::TestFile("integration", "model"));
@@ -606,6 +683,7 @@ TEST(IncludesTest, InvalidMergeInclude)
     ASSERT_FALSE(errors.empty());
     EXPECT_EQ(sdf::ErrorCode::MODEL_WITHOUT_LINK, errors[0].Code());
   }
+
   {
     const std::string sdfString = R"(
       <sdf version="1.9">
@@ -657,41 +735,36 @@ TEST(IncludesTest, InvalidMergeInclude)
     EXPECT_EQ(4, *errors[0].LineNumber());
   }
 
-  // merge-include cannot be used directly under //world
+  // merge-include can only be used directly under //model or //world
   {
     const std::string sdfString = R"(
     <sdf version="1.9">
       <world name="default">
-        <include merge="true">
-          <uri>file://merge_robot</uri> <!-- NOLINT -->
-        </include>
+        <frame name="test_frame">
+          <include merge="true">
+            <uri>file://merge_robot</uri> <!-- NOLINT -->
+          </include>
+        </frame>
       </world>
     </sdf>)";
     sdf::Root root;
     sdf::Errors errors = root.LoadSdfString(sdfString, config);
-    ASSERT_FALSE(errors.empty());
-    EXPECT_EQ(sdf::ErrorCode::MERGE_INCLUDE_UNSUPPORTED, errors[0].Code());
-    EXPECT_EQ("Merge-include does not support parent element of type world",
-              errors[0].Message());
-    EXPECT_EQ(4, errors[0].LineNumber());
+    ASSERT_EQ(3, errors.size());
+    EXPECT_EQ(sdf::ErrorCode::ELEMENT_INCORRECT_TYPE, errors[0].Code());
+    EXPECT_NE(std::string::npos, errors[0].Message().find(
+        "child of element[sensor], not defined in SDF."));
+    EXPECT_EQ(sdf::ErrorCode::ELEMENT_INCORRECT_TYPE, errors[1].Code());
+    EXPECT_NE(std::string::npos, errors[1].Message().find(
+        "XML Element[unknown_element], child of element[model], not"
+        " defined in SDF. Copying[unknown_element] as children of [model]"));
+    EXPECT_EQ(sdf::ErrorCode::MERGE_INCLUDE_UNSUPPORTED, errors[2].Code());
+    EXPECT_NE(std::string::npos, errors[2].Message().find(
+        "Merge-include does not support parent element of type frame"));
+    EXPECT_EQ(5, errors[2].LineNumber());
   }
 
   // Syntax error in included file
   {
-    // Redirect sdferr output
-    std::stringstream buffer;
-    sdf::testing::RedirectConsoleStream redir(
-        sdf::Console::Instance()->GetMsgStream(), &buffer);
-#ifdef _WIN32
-    sdf::Console::Instance()->SetQuiet(false);
-    sdf::testing::ScopeExit revertSetQuiet(
-        []
-        {
-        sdf::Console::Instance()->SetQuiet(true);
-        });
-#endif
-
-
     const std::string sdfString = R"(
     <sdf version="1.9">
       <world name="default">
@@ -702,11 +775,24 @@ TEST(IncludesTest, InvalidMergeInclude)
     </sdf>)";
     sdf::Root root;
     sdf::Errors errors = root.LoadSdfString(sdfString, config);
-    ASSERT_FALSE(errors.empty());
-    EXPECT_EQ(sdf::ErrorCode::FILE_READ, errors[0].Code());
-    EXPECT_EQ(0u, errors[0].Message().find("Unable to read file"));
-    EXPECT_EQ(5, *errors[0].LineNumber());
-    EXPECT_TRUE(buffer.str().find("Error parsing XML in file") !=
-                std::string::npos) << buffer.str();
+    ASSERT_EQ(errors.size(), 5u);
+    EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::FILE_READ);
+    EXPECT_NE(std::string::npos,
+              errors[0].Message().find("Error parsing XML in file"));
+    EXPECT_EQ(errors[1].Code(), sdf::ErrorCode::FILE_READ);
+    EXPECT_NE(std::string::npos,
+              errors[1].Message().find("Unable to read file"));
+    EXPECT_EQ(5, *errors[1].LineNumber());
+    EXPECT_EQ(errors[2].Code(), sdf::ErrorCode::ELEMENT_INVALID);
+    EXPECT_NE(std::string::npos,
+              errors[2].Message().find("Error reading element <world>"));
+    EXPECT_EQ(errors[3].Code(), sdf::ErrorCode::ELEMENT_INVALID);
+    EXPECT_NE(std::string::npos,
+              errors[3].Message().find("Error reading element <sdf>"));
+    EXPECT_EQ(errors[4].Code(), sdf::ErrorCode::STRING_READ);
+    EXPECT_NE(std::string::npos,
+              errors[4].Message().find("Unable to read SDF string"));
   }
+  // Check nothing has been printed
+  EXPECT_TRUE(buffer.str().empty()) << buffer.str();
 }
