@@ -30,8 +30,9 @@
 #include "sdf/SDFImpl.hh"
 #include "sdf/Sensor.hh"
 #include "sdf/Types.hh"
+#include "sdf/World.hh"
 #include "sdf/parser.hh"
-#include "test_config.h"
+#include "test_config.hh"
 
 //////////////////////////////////////////////////
 TEST(DOMJoint, NotAJoint)
@@ -89,10 +90,10 @@ TEST(DOMJoint, DoublePendulum)
   ASSERT_NE(nullptr, lowerJoint);
 
   // Check the parent and child link values
-  EXPECT_EQ("base", upperJoint->ParentLinkName());
-  EXPECT_EQ("upper_link", upperJoint->ChildLinkName());
-  EXPECT_EQ("upper_link", lowerJoint->ParentLinkName());
-  EXPECT_EQ("lower_link", lowerJoint->ChildLinkName());
+  EXPECT_EQ("base", upperJoint->ParentName());
+  EXPECT_EQ("upper_link", upperJoint->ChildName());
+  EXPECT_EQ("upper_link", lowerJoint->ParentName());
+  EXPECT_EQ("lower_link", lowerJoint->ChildName());
 
   // Check that the pose relative_to values are empty
   EXPECT_TRUE(upperJoint->PoseRelativeTo().empty());
@@ -157,6 +158,49 @@ TEST(DOMJoint, Complete)
   }
 }
 
+//////////////////////////////////////////////////
+TEST(DOMJoint, ScrewThreadPitch)
+{
+  const std::string testFile =
+    sdf::testing::TestFile("sdf", "joint_screw_thread_pitch.sdf");
+
+  // Load the SDF file
+  sdf::Root root;
+  sdf::Errors errors = root.Load(testFile);
+  EXPECT_TRUE(errors.empty());
+
+  // Get the first model
+  const sdf::Model *model = root.Model();
+  ASSERT_NE(nullptr, model);
+
+  EXPECT_EQ(2u, model->LinkCount());
+  EXPECT_TRUE(model->LinkNameExists("child_link"));
+  EXPECT_TRUE(model->LinkNameExists("parent_link"));
+
+  EXPECT_EQ(5u, model->JointCount());
+  ASSERT_TRUE(model->JointNameExists("default_param"));
+  ASSERT_TRUE(model->JointNameExists("both_params"));
+  ASSERT_TRUE(model->JointNameExists("new_param"));
+  ASSERT_TRUE(model->JointNameExists("old_param"));
+  ASSERT_TRUE(model->JointNameExists("param_precedence"));
+
+  EXPECT_DOUBLE_EQ(1.0,
+                   model->JointByName("default_param")->ScrewThreadPitch());
+  EXPECT_DOUBLE_EQ(0.5, model->JointByName("both_params")->ScrewThreadPitch());
+  EXPECT_DOUBLE_EQ(0.5, model->JointByName("new_param")->ScrewThreadPitch());
+  EXPECT_NEAR(0.5, model->JointByName("old_param")->ScrewThreadPitch(), 1e-3);
+  EXPECT_DOUBLE_EQ(0.5,
+                   model->JointByName("param_precedence")->ScrewThreadPitch());
+
+  EXPECT_DOUBLE_EQ(-2*GZ_PI,
+                   model->JointByName("default_param")->ThreadPitch());
+  EXPECT_NEAR(-12.566, model->JointByName("both_params")->ThreadPitch(), 1e-3);
+  EXPECT_NEAR(-12.566, model->JointByName("new_param")->ThreadPitch(), 1e-3);
+  EXPECT_DOUBLE_EQ(-12.566, model->JointByName("old_param")->ThreadPitch());
+  EXPECT_NEAR(-12.566, model->JointByName("param_precedence")->ThreadPitch(),
+              1e-3);
+}
+
 /////////////////////////////////////////////////
 TEST(DOMJoint, LoadJointParentWorld)
 {
@@ -190,8 +234,8 @@ TEST(DOMJoint, LoadJointParentWorld)
   EXPECT_NE(nullptr, model->JointByIndex(0));
   EXPECT_EQ(nullptr, model->JointByIndex(1));
   ASSERT_TRUE(model->JointNameExists("joint"));
-  EXPECT_EQ("link", model->JointByName("joint")->ChildLinkName());
-  EXPECT_EQ("world", model->JointByName("joint")->ParentLinkName());
+  EXPECT_EQ("link", model->JointByName("joint")->ChildName());
+  EXPECT_EQ("world", model->JointByName("joint")->ParentName());
   std::string resolvedLinkName;
   EXPECT_TRUE(
     model->JointByName("joint")->ResolveChildLink(resolvedLinkName).empty());
@@ -250,8 +294,8 @@ TEST(DOMJoint, LoadJointParentModelFrame)
   EXPECT_EQ(1u, model->JointCount());
   auto *joint = model->JointByName("joint");
   ASSERT_NE(nullptr, joint);
-  EXPECT_EQ("child_link", model->JointByName("joint")->ChildLinkName());
-  EXPECT_EQ("__model__", model->JointByName("joint")->ParentLinkName());
+  EXPECT_EQ("child_link", model->JointByName("joint")->ChildName());
+  EXPECT_EQ("__model__", model->JointByName("joint")->ParentName());
   std::string resolvedLinkName;
   EXPECT_TRUE(joint->ResolveParentLink(resolvedLinkName).empty());
   EXPECT_EQ("base_link", resolvedLinkName);
@@ -282,8 +326,8 @@ TEST(DOMJoint, LoadJointChildModelFrame)
   EXPECT_EQ(1u, model->JointCount());
   auto *joint = model->JointByName("joint");
   ASSERT_NE(nullptr, joint);
-  EXPECT_EQ("__model__", model->JointByName("joint")->ChildLinkName());
-  EXPECT_EQ("parent_link", model->JointByName("joint")->ParentLinkName());
+  EXPECT_EQ("__model__", model->JointByName("joint")->ChildName());
+  EXPECT_EQ("parent_link", model->JointByName("joint")->ParentName());
   std::string resolvedLinkName;
   EXPECT_TRUE(joint->ResolveChildLink(resolvedLinkName).empty());
   EXPECT_EQ("base_link", resolvedLinkName);
@@ -333,8 +377,8 @@ TEST(DOMJoint, LoadJointParentFrame)
   EXPECT_NE(nullptr, model->JointByIndex(0));
   EXPECT_EQ(nullptr, model->JointByIndex(1));
   ASSERT_TRUE(model->JointNameExists("joint"));
-  EXPECT_EQ("child_link", model->JointByName("joint")->ChildLinkName());
-  EXPECT_EQ("parent_frame", model->JointByName("joint")->ParentLinkName());
+  EXPECT_EQ("child_link", model->JointByName("joint")->ChildName());
+  EXPECT_EQ("parent_frame", model->JointByName("joint")->ParentName());
 
   std::string resolvedLinkName;
   EXPECT_TRUE(
@@ -356,7 +400,7 @@ TEST(DOMJoint, LoadJointParentFrame)
   EXPECT_EQ(Pose(1, 0, 0, 0, 0, 0),
             model->FrameByName("parent_frame")->RawPose());
 
-  // Test ResolveFrame to get each link, joint and frame pose in model frame.
+  // Test Resolve to get each link, joint and frame pose in model frame.
   Pose pose;
   EXPECT_TRUE(
     model->LinkByName("parent_link")->
@@ -425,8 +469,8 @@ TEST(DOMJoint, LoadJointChildFrame)
   EXPECT_NE(nullptr, model->JointByIndex(0));
   EXPECT_EQ(nullptr, model->JointByIndex(1));
   ASSERT_TRUE(model->JointNameExists("joint"));
-  EXPECT_EQ("child_frame", model->JointByName("joint")->ChildLinkName());
-  EXPECT_EQ("parent_link", model->JointByName("joint")->ParentLinkName());
+  EXPECT_EQ("child_frame", model->JointByName("joint")->ChildName());
+  EXPECT_EQ("parent_link", model->JointByName("joint")->ParentName());
 
   std::string resolvedLinkName;
   EXPECT_TRUE(
@@ -448,7 +492,7 @@ TEST(DOMJoint, LoadJointChildFrame)
   EXPECT_EQ(Pose(1, 0, 0, 0, 0, 0),
             model->FrameByName("child_frame")->RawPose());
 
-  // Test ResolveFrame to get each link, joint and frame pose in model frame.
+  // Test Resolve to get each link, joint and frame pose in model frame.
   Pose pose;
   EXPECT_TRUE(
     model->LinkByName("parent_link")->
@@ -478,6 +522,158 @@ TEST(DOMJoint, LoadJointChildFrame)
   EXPECT_EQ(Pose(1, 1, 9, 0, 0, 0), pose);
 }
 
+/////////////////////////////////////////////////
+TEST(DOMJoint, LoadWorldJointChildFrame)
+{
+  const std::string testFile =
+    sdf::testing::TestFile("sdf", "world_joint_child_frame.sdf");
+
+  // Load the SDF file
+  sdf::Root root;
+  auto errors = root.Load(testFile);
+  EXPECT_TRUE(errors.empty()) << errors;
+
+  using Pose = gz::math::Pose3d;
+
+  // Get the world
+  const sdf::World *world = root.WorldByIndex(0);
+  ASSERT_NE(nullptr, world);
+  EXPECT_EQ("world_joint_child_frame", world->Name());
+  EXPECT_EQ(2u, world->ModelCount());
+  EXPECT_NE(nullptr, world->ModelByIndex(0));
+  EXPECT_NE(nullptr, world->ModelByIndex(1));
+  EXPECT_EQ(nullptr, world->ModelByIndex(2));
+
+  ASSERT_TRUE(world->ModelNameExists("parent_model"));
+  ASSERT_TRUE(world->ModelNameExists("child_model"));
+  EXPECT_TRUE(world->ModelByName("parent_model")->PoseRelativeTo().empty());
+  EXPECT_TRUE(world->ModelByName("child_model")->PoseRelativeTo().empty());
+
+  EXPECT_EQ(Pose(0, 0, 1, 0, 0, 0),
+            world->ModelByName("parent_model")->RawPose());
+  EXPECT_EQ(Pose(0, 0, 10, 0, 0, 0),
+            world->ModelByName("child_model")->RawPose());
+
+  EXPECT_EQ(2u, world->JointCount());
+  EXPECT_NE(nullptr, world->JointByIndex(0));
+  EXPECT_NE(nullptr, world->JointByIndex(1));
+  EXPECT_EQ(nullptr, world->JointByIndex(2));
+  ASSERT_TRUE(world->JointNameExists("J1"));
+  ASSERT_TRUE(world->JointNameExists("J2"));
+  EXPECT_EQ("child_frame", world->JointByName("J1")->ChildName());
+  EXPECT_EQ("parent_model::L", world->JointByName("J1")->ParentName());
+  EXPECT_EQ("child_model::L", world->JointByName("J2")->ChildName());
+  EXPECT_EQ("parent_model::L", world->JointByName("J2")->ParentName());
+
+  std::string resolvedLinkName;
+  EXPECT_TRUE(
+    world->JointByName("J1")->ResolveChildLink(resolvedLinkName).empty());
+  EXPECT_EQ("child_model::L", resolvedLinkName);
+  EXPECT_TRUE(
+    world->JointByName("J1")->ResolveParentLink(resolvedLinkName).empty());
+  EXPECT_EQ("parent_model::L", resolvedLinkName);
+  EXPECT_TRUE(
+    world->JointByName("J2")->ResolveChildLink(resolvedLinkName).empty());
+  EXPECT_EQ("child_model::L", resolvedLinkName);
+  EXPECT_TRUE(
+    world->JointByName("J2")->ResolveParentLink(resolvedLinkName).empty());
+  EXPECT_EQ("parent_model::L", resolvedLinkName);
+
+  EXPECT_TRUE(world->JointByName("J1")->PoseRelativeTo().empty());
+  EXPECT_TRUE(world->JointByName("J2")->PoseRelativeTo().empty());
+  EXPECT_EQ(Pose(1, 0, 0, 0, 0, 0), world->JointByName("J1")->RawPose());
+  EXPECT_EQ(Pose(10, 0, 0, 0, 0, 0), world->JointByName("J2")->RawPose());
+
+  EXPECT_EQ(1u, world->FrameCount());
+  EXPECT_NE(nullptr, world->FrameByIndex(0));
+  EXPECT_EQ(nullptr, world->FrameByIndex(1));
+
+  ASSERT_TRUE(world->FrameNameExists("child_frame"));
+
+  EXPECT_EQ(Pose(0, 1, 0, 0, 0, 0),
+            world->FrameByName("child_frame")->RawPose());
+
+  // Test Resolve to get each model, joint and frame pose in world frame.
+  Pose pose;
+  EXPECT_TRUE(
+    world->ModelByName("parent_model")->
+      SemanticPose().Resolve(pose, "world").empty());
+  EXPECT_EQ(Pose(0, 0, 1, 0, 0, 0), pose);
+  EXPECT_TRUE(
+    world->ModelByName("child_model")->
+      SemanticPose().Resolve(pose, "world").empty());
+  EXPECT_EQ(Pose(0, 0, 10, 0, 0, 0), pose);
+  EXPECT_TRUE(
+    world->JointByName("J1")->
+      SemanticPose().Resolve(pose, "world").empty());
+  EXPECT_EQ(Pose(1, 1, 10, 0, 0, 0), pose);
+  EXPECT_TRUE(
+    world->JointByName("J2")->
+      SemanticPose().Resolve(pose, "world").empty());
+  EXPECT_EQ(Pose(10, 0, 10, 0, 0, 0), pose);
+  EXPECT_TRUE(
+    world->FrameByName("child_frame")->
+      SemanticPose().Resolve(pose, "world").empty());
+  EXPECT_EQ(Pose(0, 1, 10, 0, 0, 0), pose);
+
+  // joint frame relative to parent and child models
+  EXPECT_TRUE(
+    world->JointByName("J1")->
+      SemanticPose().Resolve(pose, "child_frame").empty());
+  EXPECT_EQ(Pose(1, 0, 0, 0, 0, 0), pose);
+  EXPECT_TRUE(
+    world->JointByName("J1")->
+      SemanticPose().Resolve(pose, "parent_model::L").empty());
+  EXPECT_EQ(Pose(1, 1, 9, 0, 0, 0), pose);
+  EXPECT_TRUE(
+    world->JointByName("J2")->
+      SemanticPose().Resolve(pose, "child_model::L").empty());
+  EXPECT_EQ(Pose(10, 0, 0, 0, 0, 0), pose);
+  EXPECT_TRUE(
+    world->JointByName("J2")->
+      SemanticPose().Resolve(pose, "parent_model::L").empty());
+  EXPECT_EQ(Pose(10, 0, 9, 0, 0, 0), pose);
+}
+
+/////////////////////////////////////////////////
+TEST(DOMJoint, WorldJointInvalidChildWorld)
+{
+  const std::string testFile =
+    sdf::testing::TestFile("sdf", "world_joint_invalid_child_world.sdf");
+
+  // Load the SDF file
+  sdf::Root root;
+  auto errors = root.Load(testFile);
+  for (auto e : errors)
+    std::cout << e << std::endl;
+  ASSERT_EQ(4u, errors.size());
+  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::JOINT_CHILD_LINK_INVALID);
+  EXPECT_NE(std::string::npos,
+    errors[0].Message().find(
+      "Joint with name[J2] specified invalid child link [world]"));
+}
+
+/////////////////////////////////////////////////
+TEST(DOMJoint, WorldJointInvalidResolvedParentSameAsChild)
+{
+  const std::string testFile =
+    sdf::testing::TestFile("sdf",
+      "world_joint_invalid_resolved_parent_same_as_child.sdf");
+
+  // Load the SDF file
+  sdf::Root root;
+  auto errors = root.Load(testFile);
+  std::cerr << errors << std::endl;
+  ASSERT_EQ(1u, errors.size());
+  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::JOINT_PARENT_SAME_AS_CHILD);
+  EXPECT_NE(std::string::npos,
+    errors[0].Message().find(
+      "joint with name[J] in world with name["
+      "joint_invalid_resolved_parent_same_as_child.sdf] specified parent "
+      "frame [child_model] and child frame [child_frame] that both resolve "
+      "to [child_model::L]"));
+}
+
 /////////////////////////////////////////////////
 TEST(DOMJoint, LoadJointPoseRelativeTo)
 {
@@ -512,9 +708,9 @@ TEST(DOMJoint, LoadJointPoseRelativeTo)
   EXPECT_TRUE(model->LinkByName("C1")->PoseRelativeTo().empty());
   EXPECT_EQ("J2", model->LinkByName("C2")->PoseRelativeTo());
 
-  EXPECT_EQ(Pose(1, 0, 0, 0, IGN_PI/2, 0), model->LinkByName("P1")->RawPose());
-  EXPECT_EQ(Pose(2, 0, 0, 0, -IGN_PI/2, 0), model->LinkByName("C1")->RawPose());
-  EXPECT_EQ(Pose(3, 0, 0, 0, IGN_PI/2, 0), model->LinkByName("P2")->RawPose());
+  EXPECT_EQ(Pose(1, 0, 0, 0, GZ_PI/2, 0), model->LinkByName("P1")->RawPose());
+  EXPECT_EQ(Pose(2, 0, 0, 0, -GZ_PI/2, 0), model->LinkByName("C1")->RawPose());
+  EXPECT_EQ(Pose(3, 0, 0, 0, GZ_PI/2, 0), model->LinkByName("P2")->RawPose());
   EXPECT_EQ(Pose(4, 0, 0, 0, 0, 0), model->LinkByName("C2")->RawPose());
 
   EXPECT_TRUE(model->CanonicalLinkName().empty());
@@ -531,33 +727,33 @@ TEST(DOMJoint, LoadJointPoseRelativeTo)
   EXPECT_EQ(Pose(0, 0, 1, 0, 0, 0), model->JointByName("J1")->RawPose());
   EXPECT_EQ(Pose(0, 0, 2, 0, 0, 0), model->JointByName("J2")->RawPose());
 
-  // Test ResolveFrame to get each link and joint pose in the model frame.
+  // Test Resolve to get each link and joint pose in the model frame.
   Pose pose;
   EXPECT_TRUE(
     model->LinkByName("P1")->
       SemanticPose().Resolve(pose, "__model__").empty());
-  EXPECT_EQ(Pose(1, 0, 0, 0, IGN_PI/2, 0), pose);
+  EXPECT_EQ(Pose(1, 0, 0, 0, GZ_PI/2, 0), pose);
   EXPECT_TRUE(
     model->LinkByName("C1")->
       SemanticPose().Resolve(pose, "__model__").empty());
-  EXPECT_EQ(Pose(2, 0, 0, 0, -IGN_PI/2, 0), pose);
+  EXPECT_EQ(Pose(2, 0, 0, 0, -GZ_PI/2, 0), pose);
   EXPECT_TRUE(
     model->JointByName("J1")->
       SemanticPose().Resolve(pose, "__model__").empty());
-  EXPECT_EQ(Pose(1, 0, 0, 0, -IGN_PI/2, 0), pose);
+  EXPECT_EQ(Pose(1, 0, 0, 0, -GZ_PI/2, 0), pose);
 
   EXPECT_TRUE(
     model->LinkByName("P2")->
       SemanticPose().Resolve(pose, "__model__").empty());
-  EXPECT_EQ(Pose(3, 0, 0, 0, IGN_PI/2, 0), pose);
+  EXPECT_EQ(Pose(3, 0, 0, 0, GZ_PI/2, 0), pose);
   EXPECT_TRUE(
     model->JointByName("J2")->
       SemanticPose().Resolve(pose, "__model__").empty());
-  EXPECT_EQ(Pose(5, 0, 0, 0, IGN_PI/2, 0), pose);
+  EXPECT_EQ(Pose(5, 0, 0, 0, GZ_PI/2, 0), pose);
   EXPECT_TRUE(
     model->LinkByName("C2")->
       SemanticPose().Resolve(pose, "__model__").empty());
-  EXPECT_EQ(Pose(5, 0, -4, 0, IGN_PI/2, 0), pose);
+  EXPECT_EQ(Pose(5, 0, -4, 0, GZ_PI/2, 0), pose);
 
   // resolve pose of J1 relative to C1, J2 relative to P2
   // these should match the numbers in the model file
@@ -650,15 +846,15 @@ TEST(DOMJoint, LoadLinkJointSameName17Invalid)
   for (auto e : errors)
     std::cout << e << std::endl;
   EXPECT_FALSE(errors.empty());
-  EXPECT_EQ(9u, errors.size());
-  EXPECT_EQ(errors[0].Code(), sdf::ErrorCode::DUPLICATE_NAME);
+  EXPECT_EQ(10u, errors.size());
+  EXPECT_EQ(errors[1].Code(), sdf::ErrorCode::DUPLICATE_NAME);
   EXPECT_NE(std::string::npos,
-    errors[0].Message().find(
+    errors[1].Message().find(
       "Joint with non-unique name [attachment] detected in model with name "
       "[link_joint_same_name]."));
-  EXPECT_EQ(errors[3].Code(), sdf::ErrorCode::DUPLICATE_NAME);
+  EXPECT_EQ(errors[4].Code(), sdf::ErrorCode::DUPLICATE_NAME);
   EXPECT_NE(std::string::npos,
-    errors[3].Message().find(
+    errors[4].Message().find(
       "Joint with non-unique name [attachment] detected in model with name "
       "[link_joint_same_name]."));
 }
@@ -710,7 +906,7 @@ TEST(DOMJoint, LoadLinkJointSameName16Valid)
   EXPECT_EQ(Pose(0, 0, 3, 0, 0, 0),
       model->JointByName("attachment_joint")->RawPose());
 
-  // Test ResolveFrame to get each link and joint pose in the model frame.
+  // Test Resolve to get each link and joint pose in the model frame.
   Pose pose;
   EXPECT_TRUE(
     model->LinkByName("base")->
@@ -844,8 +1040,8 @@ TEST(DOMJoint, LoadJointNestedParentChild)
   {
     const sdf::Joint *j1 = model->JointByName("J1");
     ASSERT_NE(nullptr, j1);
-    EXPECT_EQ("M1::L1", j1->ParentLinkName());
-    EXPECT_EQ("L1", j1->ChildLinkName());
+    EXPECT_EQ("M1::L1", j1->ParentName());
+    EXPECT_EQ("L1", j1->ChildName());
 
     std::string resolvedLinkName;
     EXPECT_TRUE(j1->ResolveParentLink(resolvedLinkName).empty());
@@ -855,13 +1051,13 @@ TEST(DOMJoint, LoadJointNestedParentChild)
 
     Pose pose;
     EXPECT_TRUE(j1->SemanticPose().Resolve(pose, "__model__").empty());
-    EXPECT_EQ(Pose(0, 0, 9, 0, IGN_PI_2, 0), pose);
+    EXPECT_EQ(Pose(0, 0, 9, 0, GZ_PI_2, 0), pose);
   }
   {
     const sdf::Joint *j2 = model->JointByName("J2");
     ASSERT_NE(nullptr, j2);
-    EXPECT_EQ("F1", j2->ParentLinkName());
-    EXPECT_EQ("L1", j2->ChildLinkName());
+    EXPECT_EQ("F1", j2->ParentName());
+    EXPECT_EQ("L1", j2->ChildName());
 
     std::string resolvedLinkName;
     EXPECT_TRUE(j2->ResolveParentLink(resolvedLinkName).empty());
@@ -871,13 +1067,13 @@ TEST(DOMJoint, LoadJointNestedParentChild)
 
     Pose pose;
     EXPECT_TRUE(j2->SemanticPose().Resolve(pose, "__model__").empty());
-    EXPECT_EQ(Pose(0, 1, 10, 0, IGN_PI_2, 0), pose);
+    EXPECT_EQ(Pose(0, 1, 10, 0, GZ_PI_2, 0), pose);
   }
   {
     const sdf::Joint *j3 = model->JointByName("J3");
     ASSERT_NE(nullptr, j3);
-    EXPECT_EQ("L1", j3->ParentLinkName());
-    EXPECT_EQ("M1::L2", j3->ChildLinkName());
+    EXPECT_EQ("L1", j3->ParentName());
+    EXPECT_EQ("M1::L2", j3->ChildName());
 
     std::string resolvedLinkName;
     EXPECT_TRUE(j3->ResolveParentLink(resolvedLinkName).empty());
@@ -892,8 +1088,8 @@ TEST(DOMJoint, LoadJointNestedParentChild)
   {
     const sdf::Joint *j4 = model->JointByName("J4");
     ASSERT_NE(nullptr, j4);
-    EXPECT_EQ("L1", j4->ParentLinkName());
-    EXPECT_EQ("M1::F1", j4->ChildLinkName());
+    EXPECT_EQ("L1", j4->ParentName());
+    EXPECT_EQ("M1::F1", j4->ChildName());
 
     std::string resolvedLinkName;
     EXPECT_TRUE(j4->ResolveParentLink(resolvedLinkName).empty());
@@ -908,8 +1104,8 @@ TEST(DOMJoint, LoadJointNestedParentChild)
   {
     const sdf::Joint *j5 = model->JointByName("J5");
     ASSERT_NE(nullptr, j5);
-    EXPECT_EQ("L1", j5->ParentLinkName());
-    EXPECT_EQ("M1::M2", j5->ChildLinkName());
+    EXPECT_EQ("L1", j5->ParentName());
+    EXPECT_EQ("M1::M2", j5->ChildName());
 
     std::string resolvedLinkName;
     EXPECT_TRUE(j5->ResolveParentLink(resolvedLinkName).empty());
@@ -919,13 +1115,13 @@ TEST(DOMJoint, LoadJointNestedParentChild)
 
     Pose pose;
     EXPECT_TRUE(j5->SemanticPose().Resolve(pose, "__model__").empty());
-    EXPECT_EQ(Pose(0, -1, 1, IGN_PI_2, 0, 0), pose);
+    EXPECT_EQ(Pose(0, -1, 1, GZ_PI_2, 0, 0), pose);
   }
   {
     const sdf::Joint *j6 = model->JointByName("J6");
     ASSERT_NE(nullptr, j6);
-    EXPECT_EQ("M1::__model__", j6->ParentLinkName());
-    EXPECT_EQ("L1", j6->ChildLinkName());
+    EXPECT_EQ("M1::__model__", j6->ParentName());
+    EXPECT_EQ("L1", j6->ChildName());
 
     std::string resolvedLinkName;
     EXPECT_TRUE(j6->ResolveParentLink(resolvedLinkName).empty());
@@ -935,13 +1131,13 @@ TEST(DOMJoint, LoadJointNestedParentChild)
 
     Pose pose;
     EXPECT_TRUE(j6->SemanticPose().Resolve(pose, "__model__").empty());
-    EXPECT_EQ(Pose(1, 0, 10, 0, IGN_PI_2, 0), pose);
+    EXPECT_EQ(Pose(1, 0, 10, 0, GZ_PI_2, 0), pose);
   }
   {
     const sdf::Joint *j7 = model->JointByName("J7");
     ASSERT_NE(nullptr, j7);
-    EXPECT_EQ("L1", j7->ParentLinkName());
-    EXPECT_EQ("M1::__model__", j7->ChildLinkName());
+    EXPECT_EQ("L1", j7->ParentName());
+    EXPECT_EQ("M1::__model__", j7->ChildName());
 
     std::string resolvedLinkName;
     EXPECT_TRUE(j7->ResolveParentLink(resolvedLinkName).empty());
