@@ -13,21 +13,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
-*/
+ */
+
+#include <string>
 
 #include <gtest/gtest.h>
 
 #include "sdf/sdf.hh"
-#include "sdf/parser_urdf.hh"
 
-#include "test_config.h"
-
-
-const std::string URDF_TEST_FILE = std::string(PROJECT_SOURCE_PATH) + "/test/performance/parser_urdf_atlas.urdf";
+#include "test_config.hh"
 
 TEST(URDFParser, AtlasURDF_5runs_performance)
 {
-   sdf::URDF2SDF parser;
-   for (int i = 0; i < 5; i++)
-       TiXmlDocument sdf_result = parser.InitModelFile(URDF_TEST_FILE);
+  const std::string URDF_TEST_FILE =
+      sdf::testing::TestFile("performance", "parser_urdf_atlas.urdf");
+
+  for (int i = 0; i < 5; i++)
+  {
+    sdf::SDFPtr root = sdf::readFile(URDF_TEST_FILE);
+  }
 }
